@@ -14,38 +14,41 @@ void new_items_move_step(
     mat& alpha_samples,
     cube& aug_rankings,
     const cube& R_obs,
-    const std::string& metric,
     const std::string& aug_method,
     const Rcpp::Nullable<arma::vec>& logz_estimate,
     const double& alpha,
-    const double& alpha_prop_sd,
-    const double& lambda,
-    const double& alpha_max,
     const uword& ttplus1,
-    const int& leap_size,
-    const bool& alpha_fixed
+    const bool& alpha_fixed,
+    const std::string& metric = "footrule",
+    const int& leap_size = 1,
+    const double& alpha_prop_sd = 0.5,
+    const double& alpha_max = 1e6,
+    const double& lambda = 0.1
 ){
   const uword num_ranks = R_obs.n_rows;
   const uword N = rho_samples.n_rows;
   int n_items = rho_samples.n_cols;
   for (uword ii = 0; ii < N; ++ii) {
     rho_samples.slice(ttplus1).row(ii) = metropolis_hastings_rho(
-      alpha_fixed ? alpha : alpha_samples(ii, ttplus1), n_items, aug_rankings.slice(ii), metric,
-      rho_samples.slice(ttplus1).row(ii).t(), leap_size
+      alpha_fixed ? alpha : alpha_samples(ii, ttplus1), n_items, aug_rankings.slice(ii),
+      rho_samples.slice(ttplus1).row(ii).t(), metric, leap_size
     ).t();
     if(!alpha_fixed){
       alpha_samples(ii, ttplus1) = metropolis_hastings_alpha(
-        alpha_samples(ii, ttplus1), n_items, aug_rankings.slice(ii), metric,
+        alpha_samples(ii, ttplus1), n_items, aug_rankings.slice(ii),
         rho_samples.slice(ttplus1).row(ii).t(), logz_estimate,
-        alpha_prop_sd, lambda, alpha_max);
+        metric, alpha_prop_sd, alpha_max, lambda
+      );
     }
 
     for (uword jj = 0; jj < num_ranks; ++jj) {
       vec mh_aug_result = metropolis_hastings_aug_ranking(                                  \
           alpha_fixed ? alpha : alpha_samples(ii, ttplus1), rho_samples.slice(ttplus1).row(ii).t(),\
           n_items, R_obs.slice(ttplus1).row(jj).t(),                                              \
-          aug_rankings.slice(ii).row(jj).t(), metric,
-          (aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman")));
+          aug_rankings.slice(ii).row(jj).t(),
+          (aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman")),
+          metric
+        );
       aug_rankings.slice(ii).row(jj) = mh_aug_result.t();
     }
   }
@@ -54,13 +57,13 @@ void new_items_move_step(
 arma::cube augment_rankings(
   const unsigned int& n_items,
   arma::cube& R_obs,
-  const std::string& metric,
   const unsigned int& N,
   arma::cube rho_samples,
   arma::mat alpha_samples,
   const double alpha = 0,
   const std::string& aug_method = "random",
-  const bool alpha_fixed = false
+  const bool alpha_fixed = false,
+  const std::string& metric = "footrule"
 ) {
   /* ====================================================== */
   /* Augment Rankings                                       */
@@ -147,8 +150,6 @@ arma::cube augment_rankings(
 Rcpp::List smc_mallows_new_item_rank(
   const unsigned int& n_items,
   arma::cube& R_obs,
-  const std::string& metric,
-  const int& leap_size,
   const unsigned int& N,
   const unsigned int Time,
   const Rcpp::Nullable<arma::vec> logz_estimate,
@@ -157,12 +158,14 @@ Rcpp::List smc_mallows_new_item_rank(
   Rcpp::Nullable<arma::mat> rho_samples_init = R_NilValue,
   arma::vec alpha_samples_init = 0,
   const double alpha = 0,
-  const double alpha_prop_sd = 1,
-  const double lambda = 1,
-  const double alpha_max = 1,
+  const double alpha_prop_sd = 0.5,
+  const double lambda = 0.1,
+  const double alpha_max = 1e6,
   const std::string& aug_method = "random",
   const bool verbose = false,
-  const bool alpha_fixed = false
+  const bool alpha_fixed = false,
+  const std::string& metric = "footrule",
+  const int& leap_size = 1
 ) {
   /* ====================================================== */
   /* Initialise Phase                                       */
@@ -207,8 +210,8 @@ Rcpp::List smc_mallows_new_item_rank(
   arma::cube aug_rankings_init_2 = aug_rankings_init.isNotNull() ? Rcpp::as<arma::cube>(aug_rankings_init) : arma::cube(0,0,0);
   if (aug_rankings_init_2.size() == 0) {
     aug_rankings = augment_rankings(
-      n_items, R_obs, metric, N, rho_samples, alpha_samples, alpha, aug_method,
-      alpha_fixed
+      n_items, R_obs, N, rho_samples, alpha_samples, alpha, aug_method,
+      alpha_fixed, metric
     );
   } else {
       aug_rankings = aug_rankings_init_2;
@@ -309,26 +312,30 @@ Rcpp::List smc_mallows_new_item_rank(
     /* Move step                                              */
     /* ====================================================== */
     new_items_move_step(
-      rho_samples, alpha_samples, aug_rankings, R_obs, metric, aug_method,
-      logz_estimate, alpha, alpha_prop_sd, lambda, alpha_max, tt + 1, leap_size,
-      alpha_fixed);
+      rho_samples, alpha_samples, aug_rankings, R_obs, aug_method,
+      logz_estimate, alpha, tt + 1,
+      alpha_fixed, metric, leap_size, alpha_prop_sd, alpha_max, lambda);
   }
 
   /* ====================================================== */
   /* Post Processing                                        */
   /* ====================================================== */
   if (alpha_fixed) {
-    return Rcpp::List::create(
+    Rcpp::List particle_history = Rcpp::List::create(
       Rcpp::Named("rho_samples") = rho_samples,
       Rcpp::Named("augmented_rankings") = aug_rankings,
       Rcpp::Named("ESS") = ESS_vec
     );
+    particle_history.attr("class") = "SMCMallows";
+    return particle_history;
   } else {
-    return Rcpp::List::create(
+    Rcpp::List particle_history = Rcpp::List::create(
       Rcpp::Named("rho_samples") = rho_samples,
       Rcpp::Named("alpha_samples") = alpha_samples,
       Rcpp::Named("augmented_rankings") = aug_rankings,
       Rcpp::Named("ESS") = ESS_vec
     );
+    particle_history.attr("class") = "SMCMallows";
+    return particle_history;
   }
 }
